Range-v3: ranges::v3::drop_view< Rng > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::drop_view< Rng > Struct Template Reference
Views
Inheritance diagram for ranges::v3::drop_view< Rng >:

## Public Member Functions
Rng & | base ()
Rng const & | base () const
iterator_t< Rng > | begin ()
template<typename BaseRng = Rng, requires = (RandomAccessRange<BaseRng const>())>
iterator_t< BaseRng const > | begin () const
| drop_view (Rng rng, difference_type_ n)
sentinel_t< Rng > | end ()
template<typename BaseRng = Rng, requires = (RandomAccessRange<BaseRng const>())>
sentinel_t< BaseRng const > | end () const
range_size_type_t< Rng > | size () const
range_size_type_t< Rng > | size ()
Public Member Functions inherited from ranges::v3::view_interface< drop_view< Rng >, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >
auto | at (range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n])
| Returns a reference to the element at specified location pos, with bounds checking.
auto | at (range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n])
range_reference_t< D > | back ()
| Access the last element in a range:
range_reference_t< D const > | back () const
constexpr bool | empty () const noexcept
constexpr bool | empty () const noexcept(noexcept(bool(ranges::begin(std::declval< D const & >())==ranges::end(std::declval< D const & >()))))
range_reference_t< D > | front ()
| Access the first element in a range:
range_reference_t< D const > | front () const
constexpr | operator bool () const noexcept(noexcept(ranges::empty(std::declval< D const & >())))
| operator Container ()
| Implicit conversion to something that looks like a container.
| operator Container () const
constexpr auto | operator! () const noexcept(noexcept(decltype(ranges::empty(std::declval< D const & >()))(ranges::empty(std::declval< D const & >())))) -> decltype(ranges::empty(std::declval< D const & >()))
view_interface & | operator= (view_interface &&)=default
view_interface & | operator= (view_interface const &)=default
auto | operator[] (range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n])
| Simple indexing:
auto | operator[] (range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n])
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
| Python-ic slicing:
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
constexpr range_size_type_t< D > | size () const noexcept
| Access the size of the range, if it can be determined:
constexpr range_size_type_t< D > | size () const
| view_interface (view_interface &&)=default
| view_interface (view_interface const &)=default

## Additional Inherited Members
Protected Member Functions inherited from ranges::v3::view_interface< drop_view< Rng >, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >
drop_view< Rng > & | derived () noexcept
constexpr drop_view< Rng > const & | derived () const noexcept

## Member Function Documentation

## ◆ begin()

template<typename Rng >

iterator_t<Rng> ranges::v3::drop_view< Rng >::begin | ( |  | ) |

Precondition
  !RandomAccessRange<Rng const>="">()

## ◆ end()

template<typename Rng >

sentinel_t<Rng> ranges::v3::drop_view< Rng >::end | ( |  | ) |

Precondition
  !RandomAccessRange<Rng const>="">()

References ranges::v3::end.

## ◆ size() [1/2]

template<typename Rng >

range_size_type_t<Rng> ranges::v3::drop_view< Rng >::size | ( |  | ) | const

Precondition
  SizedRange<Rng const>()

## ◆ size() [2/2]

template<typename Rng >

range_size_type_t<Rng> ranges::v3::drop_view< Rng >::size | ( |  | ) |

Precondition
  !SizedRange<Rng const>="">() && SizedRange<Rng>()